@@ -404,7 +404,7 @@ setRowNameGLPK <- function(lp, i, rname = NULL) {
     invisible(
         .Call("setRowName", PACKAGE = "glpkAPI",
               glpkPointer(lp),
-              i,
+              as.integer(i),
               Crname
         )
     )
@@ -412,6 +412,28 @@ setRowNameGLPK <- function(lp, i, rname = NULL) {
 }
 
 
+#------------------------------------------------------------------------------#
+
+setRowsNamesGLPK <- function(lp, i, rnames = NULL) {
+
+    if (is.null(rnames)) {
+        Crnames <- as.null(rnames)
+    }
+    else {
+        Crnames <- as.character(rnames)
+    }
+
+    invisible(
+        .Call("setRowsNames", PACKAGE = "glpkAPI",
+              glpkPointer(lp),
+              as.integer(i),
+              Crnames
+        )
+    )
+
+}
+
+
 #------------------------------------------------------------------------------#
 
 getRowNameGLPK <- function(lp, i) {
@@ -476,6 +498,28 @@ setColNameGLPK <- function(lp, j, cname = NULL) {
 }
 
 
+#------------------------------------------------------------------------------#
+
+setColsNamesGLPK <- function(lp, j, cnames = NULL) {
+
+    if (is.null(cnames)) {
+        Ccnames <- as.null(cnames)
+    }
+    else {
+        Ccnames <- as.character(cnames)
+    }
+
+    invisible(
+        .Call("setColsNames", PACKAGE = "glpkAPI",
+              glpkPointer(lp),
+              as.integer(j),
+              Ccnames
+        )
+    )
+
+}
+
+
 #------------------------------------------------------------------------------#
 
 getColNameGLPK <- function(lp, j) {
