@@ -57,10 +57,12 @@ static const R_CallMethodDef callMethods[] = {
     {"getObjDir",           (DL_FUNC) &getObjDir,           1},
     {"addRows",             (DL_FUNC) &addRows,             2},
     {"setRowName",          (DL_FUNC) &setRowName,          3},
+    {"setRowsNames",        (DL_FUNC) &setRowsNames,        3},
     {"getRowName",          (DL_FUNC) &getRowName,          2},
     {"findRow",             (DL_FUNC) &findRow,             2},
     {"addCols",             (DL_FUNC) &addCols,             2},
     {"setColName",          (DL_FUNC) &setColName,          3},
+    {"setColsNames",        (DL_FUNC) &setColsNames,        3},
     {"getColName",          (DL_FUNC) &getColName,          2},
     {"findCol",             (DL_FUNC) &findCol,             2},
     {"getNumRows",          (DL_FUNC) &getNumRows,          1},
